# -*- coding: utf-8 -*-
"""Default package."""

from corenetworks.client import CoreNetworks  # noqa

__author__ = "Robert Kaussow"
__project__ = "corenetworks"
__license__ = "MIT"
__maintainer__ = "Robert Kaussow"
__email__ = "mail@thegeeklab.de"
__url__ = "https://github.com/thegeeklab/corenetworks"
__version__ = "0.1.6"
